==> apache-streampipes-0.91.0-source-release.zip: apache-streampipes-0.91.0/ui/src/app/core-ui/pipeline-element-template-config/pipeline-element-template.pipe.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

import { Injectable, Pipe, PipeTransform } from '@angular/core';
import {
    RuntimeResolvableAnyStaticProperty,
    RuntimeResolvableOneOfStaticProperty,
    RuntimeResolvableTreeInputStaticProperty,
    StaticPropertyUnion,
} from '@streampipes/platform-services';

@Pipe({ name: 'pipelineElementTemplatePipe' })
@Injectable({ providedIn: 'root' })
export class PipelineElementTemplatePipe implements PipeTransform {
    transform(properties: StaticPropertyUnion[]): StaticPropertyUnion[] {
        return properties.filter(
            p =>
                !(p instanceof RuntimeResolvableAnyStaticProperty) &&
                !(
                    p instanceof RuntimeResolvableOneOfStaticProperty &&
                    !(p instanceof RuntimeResolvableTreeInputStaticProperty)
                ),
        );
    }
}

==> apache-streampipes-0.97.0-source-release.zip: apache-streampipes-0.97.0/ui/src/app/core-ui/pipeline-element-template-config/pipeline-element-template.pipe.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

import { Injectable, Pipe, PipeTransform } from '@angular/core';
import {
    MappingPropertyNary,
    MappingPropertyUnary,
    RuntimeResolvableAnyStaticProperty,
    RuntimeResolvableOneOfStaticProperty,
    RuntimeResolvableTreeInputStaticProperty,
    StaticPropertyUnion,
} from '@streampipes/platform-services';

@Pipe({ name: 'pipelineElementTemplatePipe' })
@Injectable({ providedIn: 'root' })
export class PipelineElementTemplatePipe implements PipeTransform {
    transform(properties: StaticPropertyUnion[]): StaticPropertyUnion[] {
        return properties.filter(
            p =>
                !(p instanceof RuntimeResolvableAnyStaticProperty) &&
                !(
                    p instanceof RuntimeResolvableOneOfStaticProperty &&
                    !(p instanceof RuntimeResolvableTreeInputStaticProperty)
                ) &&
                !(p instanceof MappingPropertyUnary) &&
                !(p instanceof MappingPropertyNary),
        );
    }
}
